@@ -265,6 +265,20 @@ func TestConformanceInternal(t *testing.T) {
 			Name:       "copy to dir",
 			ContextDir: "testdata/copy",
 		},
+		{
+			Name:       "copy chown",
+			ContextDir: "testdata/copychown",
+		},
+		{
+			Name:       "copy empty 1",
+			ContextDir: "testdata/copyempty",
+			Dockerfile: "Dockerfile",
+		},
+		{
+			Name:       "copy empty 2",
+			ContextDir: "testdata/copyempty",
+			Dockerfile: "Dockerfile2",
+		},
 		{
 			Name:       "copy dir",
 			ContextDir: "testdata/copydir",
@@ -273,6 +287,21 @@ func TestConformanceInternal(t *testing.T) {
 			Name:       "copy to renamed file",
 			ContextDir: "testdata/copyrename",
 		},
+		{
+			Name:       "copy subdirectory 1",
+			ContextDir: "testdata/copyblahblub",
+			Dockerfile: "Dockerfile",
+		},
+		{
+			Name:       "copy subdirectory 2",
+			ContextDir: "testdata/copyblahblub",
+			Dockerfile: "Dockerfile2",
+		},
+		{
+			Name:       "copy subdirectory 3",
+			ContextDir: "testdata/copyblahblub",
+			Dockerfile: "Dockerfile3",
+		},
 		{
 			Name:       "directory with slash",
 			ContextDir: "testdata/overlapdir",
